[FFmpeg-devel] [PATCH 2/3] avisynth: Bump minimum required version to interface version 6

Stephen Hutchinson qyot27 at gmail.com
Thu Apr 2 21:38:54 CEST 2015


The AVSC_API changes in the new headers mean that the 2.6 alphas
are just as incompatible as 2.5 is.
---
 libavformat/avisynth.c | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/libavformat/avisynth.c b/libavformat/avisynth.c
index 84b7d04..4af58f6 100644
--- a/libavformat/avisynth.c
+++ b/libavformat/avisynth.c
@@ -406,13 +406,14 @@ static int avisynth_open_file(AVFormatContext *s)
     avs->vi   = avs_library.avs_get_video_info(avs->clip);
 
 #ifdef USING_AVISYNTH
     /* FFmpeg only supports AviSynth 2.6 on Windows. Since AvxSynth
      * identifies itself as interface version 3 like 2.5.8, this
      * needs to be special-cased. */
 
-    if (avs_library.avs_get_version(avs->clip) == 3) {
+    if (avs_library.avs_get_version(avs->clip) < 6) {
         av_log(s, AV_LOG_ERROR,
-               "AviSynth 2.5.8 not supported. Please upgrade to 2.6.\n");
+               "AviSynth version is too old. Please upgrade to either AviSynth 2.6 >= RC1 or AviSynth+ >= r1718.\n");
         ret = AVERROR_UNKNOWN;
         goto fail;
     }
@@ -406,13 +406,14 @@ static int avisynth_open_file(AVFormatContext *s)
 
 #ifdef USING_AVISYNTH
-    /* FFmpeg only supports AviSynth 2.6 on Windows. Since AvxSynth
-     * identifies itself as interface version 3 like 2.5.8, this
-     * needs to be special-cased. */
+    /* On Windows, FFmpeg supports AviSynth interface version 6 or higher.
+     * This includes AviSynth 2.6 RC1 or higher, and AviSynth+ r1718 or higher,
+     * and excludes 2.5 and the 2.6 alphas. Since AvxSynth identifies itself
+     * as interface version 3 like 2.5.8, this needs to be special-cased. */
 
-- 
2.1.0



More information about the ffmpeg-devel mailing list